// ==UserScript==
// @name        MouseHunt Improved Userscript Migration
// @version     1.1.1
// @description Migrate users to the new MouseHunt Improved browser extension.
// @license     MIT
// @author      brap
// @namespace   bradp
// @match       https://www.mousehuntgame.com/*
// @icon        https://i.mouse.rip/mouse.png
// @run-at      document-end
// @grant       none
// ==/UserScript==
const showMigrationPopup = () => {
    if (window.mhuiMigrateUserscriptsShown) {
        return;
    }

    // set the flag to true so that we don't show the popup again.
    window.mhuiMigrateUserscriptsShown = true;

    // If we don't have jsDialog, bail.
    if ('undefined' === typeof jsDialog || !jsDialog) { // eslint-disable-line no-undef
        return;
    }

    // Add the styles for our popup.
    const hasStyles = document.querySelector('#mh-improved-migration-styles');
    if (! hasStyles) {
        const styles = document.createElement('style');
        styles.id = 'mh-improved-migration-styles';
        styles.innerHTML = `#overlayPopup.mhui-migration-popup .jsDialog.top,
        #overlayPopup.mhui-migration-popup .jsDialog.bottom,
        #overlayPopup.mhui-migration-popup .jsDialog.background {
            padding: 0;
            margin: 0;
            background: none;
        }

        #overlayPopup.mhui-migration-popup .jsDialogContainer .prefix,
        #overlayPopup.mhui-migration-popup .jsDialogContainer .content {
            padding: 0;
        }

        #overlayPopup.mhui-migration-popup #jsDialogClose,
        #overlayPopup.mhui-migration-popup .jsDialogContainer .suffix {
            display: none;
        }

        #overlayPopup.mhui-migration-popup .jsDialogContainer {
            padding: 0 20px;
            background-image: url(https://www.mousehuntgame.com/images/ui/newsposts/np_border.png);
            background-repeat: repeat-y;
            background-size: 100%;
        }

        #overlayPopup.mhui-migration-popup .jsDialogContainer::before {
            position: absolute;
            top: -80px;
            right: 0;
            left: 0;
            height: 100px;
            content: "";
            background-image: url(https://www.mousehuntgame.com/images/ui/newsposts/np_header.png);
            background-repeat: no-repeat;
            background-size: 100%;
        }

        #overlayPopup.mhui-migration-popup .jsDialogContainer::after {
            position: absolute;
            top: 100%;
            right: 0;
            left: 0;
            height: 126px;
            content: "";
            background-image: url(https://www.mousehuntgame.com/images/ui/newsposts/np_footer.png);
            background-repeat: no-repeat;
            background-size: 100%;
        }

        .mhui-migration-wrapper {
            margin: 0 2em;
        }

        .mhui-migration-wrapper,
        .mhui-migration-wrapper p {
            font-size: 1.1em;
            line-height: 1.5;
        }

        .mhui-migration-title {
            padding: 10px 0;
            font-size: 1.5em;
            font-weight: 700;
        }

        .mhui-migration-buttons {
            display: flex;
            gap: 10px;
            align-items: center;
            justify-content: center;
            flex-direction: column;
        }

        .mhui-migration-list {
            margin: 10px;
        }`;

        document.head.append(styles);
    }

    const userscripts = window.mhuiMigrateUserscripts || [];
    let list = '';
    userscripts.forEach((userscript) => {
        list += `<li class="mhui-migration-list-item"><a href="${userscript.link}" target="_userscripts">${userscript.name}</a></li>`;
    });

    let extLink = '';
    if (navigator.userAgent.includes('Firefox')) {
        extLink = 'https://addons.mozilla.org/en-US/firefox/addon/mousehunt-improved/'
        extText = 'View in Firefox Addons';
    } else if (navigator.userAgent.includes('Chrome')) {
        extLink = 'https://chrome.google.com/webstore/detail/mousehunt-improved/fgjkidgknmkhnbeobehlfabjbignhkhm';
        extText = 'View in Chrome Web Store';
    } else {
        extLink = 'https://github.com/MHCommunity/mousehunt-improved';
        extText = 'View on GitHub';
    }

    // Build the markup with our content.
    const markup = `<div class="mhui-migration-wrapper">
        <h2 class="mhui-migration-title">Important Message about your installed UserScripts!</h2>
        <p>The following installed scripts are now a part of <a href="${extLink}" target="_blank">MouseHunt Improved</a>:</p>
        <ul class="mhui-migration-list">${list}</ul>
        <p><a href="https://github.com/MHCommunity/mousehunt-improved">MouseHunt Improved</a> is a new browser extension for MouseHunt packed with over 150 features to make your hunting experience better than ever!</p>
        <p>More information and a list of the features is available on <a href="https://github.com/MHCommunity/mousehunt-improved">GitHub</a>.</p>
        <div class="mhui-migration-buttons">
            <a href="${extLink}" class="mousehuntActionButton lightBlue mh-migration-popup-install" target="_blank"><span>${extText}</span></a>
            <a href="#" class="mousehuntActionButton tiny mh-migration-popup-close"><span>Close</span></a>
        </div>
        </div>
    </div>`;

    // Initiate the popup.
    const popup = new jsDialog();
    popup.setIsModal(true);
    popup.setTemplate('ajax');
    popup.addToken('{*prefix*}', '');
    popup.addToken('{*content*}', markup);
    popup.addToken('{*suffix*}', '');
    popup.setAttributes({ className: 'mhui-migration-popup' });
    popup.show();

    const button = document.querySelector('.mh-migration-popup-close');
    button.addEventListener('click', () => {
        popup.hide();
        localStorage.setItem('mh-improved-ignore-migrated-userscript-warning', true);
    });

    const installButton = document.querySelector('.mh-migration-popup-install');
    installButton.addEventListener('click', () => {
        localStorage.setItem('mh-improved-ignore-migrated-userscript-warning', true);
    });
};

const migrateUserscript = (name, link) => {
    if (localStorage.getItem('mh-improved-ignore-migrated-userscript-warning') === 'true') {
        return;
    }

    window.mhuiMigrateUserscripts = window.mhuiMigrateUserscripts || [];
    window.mhuiMigrateUserscripts.push({ name, link });

    // wait a second for all the userscripts to load, then show the popup unless it's already been shown.
    // in order to prevent a race condition of all the userscripts trying to show the popup at the same time, we'll set a flag to make sure it only shows once and
    // we'll base the timeout on the length of the userscripts array, so that the last userscript to load will be the one to show the popup.
    // console.log(15000 / window.mhuiMigrateUserscripts.length);
    // wait for all the userscripts to load, then show the popup.
    setTimeout(() => {
        showMigrationPopup();
    }, 10000 / window.mhuiMigrateUserscripts.length);
};
